summaryrefslogtreecommitdiff
path: root/expt_0406.cu
diff options
context:
space:
mode:
authorKunoiSayami <[email protected]>2023-07-02 21:53:47 +0800
committerKunoiSayami <[email protected]>2023-07-02 21:53:47 +0800
commitc71e687de86691c0149804ef10721ac9c230ab9e (patch)
treec5edef26ed08eeea4c4479016faea2dbcca7430c /expt_0406.cu
parent0b09bc40d295e7b383f2e5c8ddba255f0ac680ca (diff)
refactor: Change basic function name
Signed-off-by: KunoiSayami <[email protected]>
Diffstat (limited to 'expt_0406.cu')
-rw-r--r--expt_0406.cu4
1 files changed, 2 insertions, 2 deletions
diff --git a/expt_0406.cu b/expt_0406.cu
index 30ee7c4..4e9ec89 100644
--- a/expt_0406.cu
+++ b/expt_0406.cu
@@ -56,8 +56,8 @@ __global__ void kernel(unsigned long step, const double slice_size) {
auto tid = step * (blockIdx.x * blockDim.x + threadIdx.x) + i;
// printf("%d\n", tid);
- auto index = (int)(FactorySort::sample_cdf(cudaSampleItem, length,
- cudaPopulationItem[tid]) /
+ auto index = (int)(FactorySort::cdf(cudaSampleItem, length,
+ cudaPopulationItem[tid]) /
slice_size);
cdf_result[index] = true;